function [data, comp_data, bnet_miss, taux, bnet_orig, notok] = gener_data_from_bnet_miss(bnet_miss, m, base_proba ,v, testdata)
% [data, comp_data, bnet_miss, taux, bnet_orig, notok] = gener_data_from_bnet_miss(bnet_miss, m, base_proba ,v, aretestdata)
%

% Initialisation

if nargin<5, testdata = 0; end
if nargin<4, v = 1; end

N2 = length(bnet_miss.dag); 
if mod(N2,2)~=0, error('The number of nodes must be even in bnet_miss'); end
N = length(bnet_miss.dag)/2;

if nargin<3, 
    error('Not enougth parameters'); 
    CPT = CPT_from_bnet(bnet_miss,0);
    base_probs = zeros(1,N);
    for i=N+1:N2
        CPTT = CPT{i};
        fam = find(bnet_miss.dag(:,i)==1)';
        semisize = prod(bnet_miss.node_sizes(fam)); % as node N+i is binary to say i is present or missing
        base_probs(i-N) = mean(CPTT(semisize+1:2*semisize));
    end
    base_proba = mean(base_probs);
end
if nargin<2, error('Not enougth parameters'); end

% CHOOSE THE TEST POWER (only affect 'notok' value)
                    chi2_0_1_1fd  =  2.705 ;
                   chi2_0_05_1fd  =  3.841 ;
                   chi2_0_01_1fd  =  6.635 ;
                   chi2_0_001_1fd = 10.827 ;
                  chi2_0_0001_1fd = 15.137 ;
                                            choice = chi2_0_1_1fd;
notok=0;                             
clear chi2_0_1_1fd chi2_0_05_1fd chi2_0_01_1fd chi2_0_001_1fd chi2_0_0001_1fd

% Recovering bnet_orig

dag = bnet_miss.dag(1:N,1:N);
bnet_orig = mk_bnet(dag, bnet_miss.node_sizes(1:N));
CPT = CPT_from_bnet(bnet_miss, 0);
for i=1:N, bnet_orig.CPD{i} = tabular_CPD(bnet_orig, i, CPT{i}); end

% Generation of complete data

if testdata, rand('state',0); randn('state',0); end

data = cell(N,m);
for l = 1:m, data(:,l) = sample_bnet(bnet_orig); end
fprintf('Complete data have been created.\n');

% Generation of missing array

miss_array = cell(2*N,m);
vide = cell(1,N); l= 1;
while l <= m, 
  ev(1:N) = data(:,l); ev(N+1:2*N) = vide;
  miss_array(:,l) = sample_bnet(bnet_miss, 'evidence', ev); 
  % apply simple rule of missingness
  ev2 = cell2mat(miss_array(N+1:2*N, l));
  % verification that we have not a completly missing sample
  ev2 = 3-ev2; 
  if prod(ev2)==1, 
    if v, fprintf(' - %d, one completly missing sample removed', l);end
  else l=l+1;
  end 
  if v, if mod(l,100)==0, fprintf('\n - %d',l); end,  end
end
if v, fprintf('\n'); end
miss_array = bnt_to_mat(miss_array(N+1:2*N, :)); 
miss_array = 2-miss_array; 

% Generation of incomplete dataset

data = bnt_to_mat(data); 
comp_data = data; 
data = data.*miss_array; 
data = mat_to_bnt(data, 0); 
fprintf('Incomplete dataset have been created.\n');

% rate of missing data

[XX, YY]=find(miss_array==0);
nbr_miss = length(YY);
taux = nbr_miss/N/m;
if v, fprintf('There is %2.2f percent of missing data\n', round(taux*10000)/100); end

% Khi2 test between taux and base_proba for m*N

toto = m*N;
d = ((nbr_miss-base_proba*toto)^2)/(base_proba*toto) + (((toto-nbr_miss)-(1-base_proba)*toto)^2)/((1-base_proba)*toto);
if d>choice, 
  fprintf('THE DATASET DO NOT RESPECT %2.1f%% OF MISSING DATA (%2.1f%%, Khi2 : %2.1f > %2.1f)\n', round(base_proba*10000)/100, round(taux*10000)/100, d, choice); 
  notok = 1;
end
